Target

Struct Target 

#[non_exhaustive]
pub struct Target { pub target: Option<Target>, /* private fields */ }
Target is the full resource name of the resource to which the policy will be bound. Immutable once set.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
target: Option<Target>

The different types of targets that can be bound to a policy.

Implementations

Source

impl Target

pub fn new() -> Self

pub fn set_target<T: Into<Option<Target>>>(self, v: T) -> Self

Sets the value of target.

Note that all the setters affecting target are mutually exclusive.

Example
use google_cloud_iam_v3::model::policy_binding::target::Target as TargetOneOf;
let x = Target::new().set_target(Some(TargetOneOf::PrincipalSet("example".to_string())));
pub fn principal_set(&self) -> Option<&String>

The value of target if it holds a PrincipalSet, None if the field is not set or holds a different branch.

pub fn set_principal_set<T: Into<String>>(self, v: T) -> Self

Sets the value of target to hold a PrincipalSet.

Note that all the setters affecting target are mutually exclusive.

Example
let x = Target::new().set_principal_set("example");
assert!(x.principal_set().is_some());