Target

Enum Target 

#[non_exhaustive]
pub enum Target { PrincipalSet(String), }
The different types of targets that can be bound to a policy.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


PrincipalSet(String)

Immutable. Full Resource Name used for principal access boundary policy bindings. The principal set must be directly parented by the policy binding’s parent or same as the parent if the target is a project/folder/organization.

Examples:

  • For binding’s parented by an organization:
    • Organization: //cloudresourcemanager.googleapis.com/organizations/ORGANIZATION_ID
    • Workforce Identity: //iam.googleapis.com/locations/global/workforcePools/WORKFORCE_POOL_ID
    • Workspace Identity: //iam.googleapis.com/locations/global/workspace/WORKSPACE_ID
  • For binding’s parented by a folder:
    • Folder: //cloudresourcemanager.googleapis.com/folders/FOLDER_ID
  • For binding’s parented by a project:
    • Project:
      • //cloudresourcemanager.googleapis.com/projects/PROJECT_NUMBER
      • //cloudresourcemanager.googleapis.com/projects/PROJECT_ID
    • Workload Identity Pool: //iam.googleapis.com/projects/PROJECT_NUMBER/locations/LOCATION/workloadIdentityPools/WORKLOAD_POOL_ID