CreatePrincipalAccessBoundaryPolicyRequest

Struct CreatePrincipalAccessBoundaryPolicyRequest 

#[non_exhaustive]
pub struct CreatePrincipalAccessBoundaryPolicyRequest { pub parent: String, pub principal_access_boundary_policy_id: String, pub principal_access_boundary_policy: Option<PrincipalAccessBoundaryPolicy>, pub validate_only: bool, /* private fields */ }
Request message for CreatePrincipalAccessBoundaryPolicyRequest method.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
parent: String

Required. The parent resource where this principal access boundary policy will be created. Only organizations are supported.

Format: organizations/{organization_id}/locations/{location}

principal_access_boundary_policy_id: String

Required. The ID to use for the principal access boundary policy, which will become the final component of the principal access boundary policy’s resource name.

This value must start with a lowercase letter followed by up to 62 lowercase letters, numbers, hyphens, or dots. Pattern, /[a-z][a-z0-9-.]{2,62}/.

principal_access_boundary_policy: Option<PrincipalAccessBoundaryPolicy>

Required. The principal access boundary policy to create.

validate_only: bool

Optional. If set, validate the request and preview the creation, but do not actually post it.

Implementations

Source

impl CreatePrincipalAccessBoundaryPolicyRequest

pub fn new() -> Self

pub fn set_parent<T: Into<String>>(self, v: T) -> Self

Sets the value of parent.

Example
let x = CreatePrincipalAccessBoundaryPolicyRequest::new().set_parent("example");
pub fn set_principal_access_boundary_policy_id<T: Into<String>>( self, v: T, ) -> Self

Sets the value of principal_access_boundary_policy_id.

Example
let x = CreatePrincipalAccessBoundaryPolicyRequest::new().set_principal_access_boundary_policy_id("example");
pub fn set_principal_access_boundary_policy<T>(self, v: T) -> Self

Sets the value of principal_access_boundary_policy.

Example
use google_cloud_iam_v3::model::PrincipalAccessBoundaryPolicy;
let x = CreatePrincipalAccessBoundaryPolicyRequest::new().set_principal_access_boundary_policy(PrincipalAccessBoundaryPolicy::default()/* use setters */);
pub fn set_or_clear_principal_access_boundary_policy<T>( self, v: Option<T>, ) -> Self

Sets or clears the value of principal_access_boundary_policy.

Example
use google_cloud_iam_v3::model::PrincipalAccessBoundaryPolicy;
let x = CreatePrincipalAccessBoundaryPolicyRequest::new().set_or_clear_principal_access_boundary_policy(Some(PrincipalAccessBoundaryPolicy::default()/* use setters */));
let x = CreatePrincipalAccessBoundaryPolicyRequest::new().set_or_clear_principal_access_boundary_policy(None::<PrincipalAccessBoundaryPolicy>);
pub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self

Sets the value of validate_only.

Example
let x = CreatePrincipalAccessBoundaryPolicyRequest::new().set_validate_only(true);