#[non_exhaustive]pub struct DeletePolicyBindingRequest {
pub name: String,
pub etag: String,
pub validate_only: bool,
/* private fields */
}Expand description
Request message for DeletePolicyBinding method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The name of the policy binding to delete.
Format:
projects/{project_id}/locations/{location}/policyBindings/{policy_binding_id}projects/{project_number}/locations/{location}/policyBindings/{policy_binding_id}folders/{folder_id}/locations/{location}/policyBindings/{policy_binding_id}organizations/{organization_id}/locations/{location}/policyBindings/{policy_binding_id}
etag: StringOptional. The etag of the policy binding. If this is provided, it must match the server’s etag.
validate_only: boolOptional. If set, validate the request and preview the deletion, but do not actually post it.
Implementations
Sourceimpl DeletePolicyBindingRequest
impl DeletePolicyBindingRequest
pub fn new() -> Self
Sourcepub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
pub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
Sets the value of validate_only.
Example
ⓘ
let x = DeletePolicyBindingRequest::new().set_validate_only(true);Trait Implementations
Sourceimpl Clone for DeletePolicyBindingRequest
impl Clone for DeletePolicyBindingRequest
Sourcefn clone(&self) -> DeletePolicyBindingRequest
fn clone(&self) -> DeletePolicyBindingRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeletePolicyBindingRequest
impl Debug for DeletePolicyBindingRequest
Sourceimpl Default for DeletePolicyBindingRequest
impl Default for DeletePolicyBindingRequest
Sourcefn default() -> DeletePolicyBindingRequest
fn default() -> DeletePolicyBindingRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for DeletePolicyBindingRequest
impl Message for DeletePolicyBindingRequest
impl StructuralPartialEq for DeletePolicyBindingRequest