#[non_exhaustive]pub struct SearchTargetPolicyBindingsRequest {
pub target: String,
pub page_size: i32,
pub page_token: String,
pub parent: String,
/* private fields */
}Expand description
Request message for SearchTargetPolicyBindings method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.target: StringRequired. The target resource, which is bound to the policy in the binding.
Format:
//iam.googleapis.com/locations/global/workforcePools/POOL_ID//iam.googleapis.com/projects/PROJECT_NUMBER/locations/global/workloadIdentityPools/POOL_ID//iam.googleapis.com/locations/global/workspace/WORKSPACE_ID//cloudresourcemanager.googleapis.com/projects/{project_number}//cloudresourcemanager.googleapis.com/folders/{folder_id}//cloudresourcemanager.googleapis.com/organizations/{organization_id}
page_size: i32Optional. The maximum number of policy bindings to return. The service may return fewer than this value.
If unspecified, at most 50 policy bindings will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.
page_token: StringOptional. A page token, received from a previous
SearchTargetPolicyBindingsRequest call. Provide this to retrieve the
subsequent page.
When paginating, all other parameters provided to
SearchTargetPolicyBindingsRequest must match the call that provided the
page token.
parent: StringRequired. The parent resource where this search will be performed. This should be the nearest Resource Manager resource (project, folder, or organization) to the target.
Format:
projects/{project_id}/locations/{location}projects/{project_number}/locations/{location}folders/{folder_id}/locations/{location}organizations/{organization_id}/locations/{location}
Implementations
Sourceimpl SearchTargetPolicyBindingsRequest
impl SearchTargetPolicyBindingsRequest
pub fn new() -> Self
Sourcepub fn set_target<T: Into<String>>(self, v: T) -> Self
pub fn set_target<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = SearchTargetPolicyBindingsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for SearchTargetPolicyBindingsRequest
impl Clone for SearchTargetPolicyBindingsRequest
Sourcefn clone(&self) -> SearchTargetPolicyBindingsRequest
fn clone(&self) -> SearchTargetPolicyBindingsRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for SearchTargetPolicyBindingsRequest
impl Default for SearchTargetPolicyBindingsRequest
Sourcefn default() -> SearchTargetPolicyBindingsRequest
fn default() -> SearchTargetPolicyBindingsRequest
Sourceimpl PartialEq for SearchTargetPolicyBindingsRequest
impl PartialEq for SearchTargetPolicyBindingsRequest
Sourcefn eq(&self, other: &SearchTargetPolicyBindingsRequest) -> bool
fn eq(&self, other: &SearchTargetPolicyBindingsRequest) -> bool
self and other values to be equal, and is used by ==.