#[non_exhaustive]pub struct SearchTargetPolicyBindingsResponse {
pub policy_bindings: Vec<PolicyBinding>,
pub next_page_token: String,
/* private fields */
}Expand description
Response message for SearchTargetPolicyBindings method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.policy_bindings: Vec<PolicyBinding>The policy bindings bound to the specified target.
next_page_token: StringOptional. A token, which can be sent as page_token to retrieve the next
page. If this field is omitted, there are no subsequent pages.
Implementations
Sourceimpl SearchTargetPolicyBindingsResponse
impl SearchTargetPolicyBindingsResponse
pub fn new() -> Self
Sourcepub fn set_policy_bindings<T, V>(self, v: T) -> Self
pub fn set_policy_bindings<T, V>(self, v: T) -> Self
Sets the value of policy_bindings.
Example
ⓘ
use google_cloud_iam_v3::model::PolicyBinding;
let x = SearchTargetPolicyBindingsResponse::new()
.set_policy_bindings([
PolicyBinding::default()/* use setters */,
PolicyBinding::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = SearchTargetPolicyBindingsResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for SearchTargetPolicyBindingsResponse
impl Clone for SearchTargetPolicyBindingsResponse
Sourcefn clone(&self) -> SearchTargetPolicyBindingsResponse
fn clone(&self) -> SearchTargetPolicyBindingsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for SearchTargetPolicyBindingsResponse
impl Default for SearchTargetPolicyBindingsResponse
Sourcefn default() -> SearchTargetPolicyBindingsResponse
fn default() -> SearchTargetPolicyBindingsResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for SearchTargetPolicyBindingsResponse
impl PartialEq for SearchTargetPolicyBindingsResponse
Sourcefn eq(&self, other: &SearchTargetPolicyBindingsResponse) -> bool
fn eq(&self, other: &SearchTargetPolicyBindingsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SearchTargetPolicyBindingsResponse