#[non_exhaustive]pub struct UpdatePolicyBindingRequest {
pub policy_binding: Option<PolicyBinding>,
pub validate_only: bool,
pub update_mask: Option<FieldMask>,
/* private fields */
}Expand description
Request message for UpdatePolicyBinding method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.policy_binding: Option<PolicyBinding>Required. The policy binding to update.
The policy binding’s name field is used to identify the policy binding to
update.
validate_only: boolOptional. If set, validate the request and preview the update, but do not actually post it.
update_mask: Option<FieldMask>Optional. The list of fields to update
Implementations
Sourceimpl UpdatePolicyBindingRequest
impl UpdatePolicyBindingRequest
pub fn new() -> Self
Sourcepub fn set_policy_binding<T>(self, v: T) -> Selfwhere
T: Into<PolicyBinding>,
pub fn set_policy_binding<T>(self, v: T) -> Selfwhere
T: Into<PolicyBinding>,
Sets the value of policy_binding.
Example
ⓘ
use google_cloud_iam_v3::model::PolicyBinding;
let x = UpdatePolicyBindingRequest::new().set_policy_binding(PolicyBinding::default()/* use setters */);Sourcepub fn set_or_clear_policy_binding<T>(self, v: Option<T>) -> Selfwhere
T: Into<PolicyBinding>,
pub fn set_or_clear_policy_binding<T>(self, v: Option<T>) -> Selfwhere
T: Into<PolicyBinding>,
Sets or clears the value of policy_binding.
Example
ⓘ
use google_cloud_iam_v3::model::PolicyBinding;
let x = UpdatePolicyBindingRequest::new().set_or_clear_policy_binding(Some(PolicyBinding::default()/* use setters */));
let x = UpdatePolicyBindingRequest::new().set_or_clear_policy_binding(None::<PolicyBinding>);Sourcepub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
pub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
Sets the value of validate_only.
Example
ⓘ
let x = UpdatePolicyBindingRequest::new().set_validate_only(true);Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdatePolicyBindingRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdatePolicyBindingRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdatePolicyBindingRequest::new().set_or_clear_update_mask(None::<FieldMask>);Trait Implementations
Sourceimpl Clone for UpdatePolicyBindingRequest
impl Clone for UpdatePolicyBindingRequest
Sourcefn clone(&self) -> UpdatePolicyBindingRequest
fn clone(&self) -> UpdatePolicyBindingRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdatePolicyBindingRequest
impl Debug for UpdatePolicyBindingRequest
Sourceimpl Default for UpdatePolicyBindingRequest
impl Default for UpdatePolicyBindingRequest
Sourcefn default() -> UpdatePolicyBindingRequest
fn default() -> UpdatePolicyBindingRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for UpdatePolicyBindingRequest
impl Message for UpdatePolicyBindingRequest
impl StructuralPartialEq for UpdatePolicyBindingRequest