#[non_exhaustive]pub struct Target {
pub target: Option<Target>,
/* private fields */
}Expand description
Target is the full resource name of the resource to which the policy will be bound. Immutable once set.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.target: Option<Target>The different types of targets that can be bound to a policy.
Implementations